/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file        rua.h
 * @brief       RUA INTERNAL API declaration header file.
 * @author      hyunho kang (hhstark.kang@samsung.com)
 * @version     0.1
 * @history     0.1: RUA INTERNAL API Declarations, structure declaration
 */

#ifndef __RUA_INTERNAL_H__
#define __RUA_INTERNAL_H__

#include <sys/types.h>
#include <bundle.h>

#include "rua.h"

#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief	Delete history from DB
 * @return	0 on success, otherwise a nagative error value
 * @retval	0 on successful
 * @retval	-1 on failed
 */
int rua_db_delete_history(bundle *b);
int rua_usr_db_delete_history(bundle *b, uid_t uid);

/**
 * @brief	Add application to recently used application list
 * @param[in]	rec  record to add history
 * @return	0 on success, otherwise a nagative error value
 * @retval	0 on successful
 * @retval	-1 on failed
 */
int rua_db_add_history(struct rua_rec *rec);
int rua_usr_db_add_history(struct rua_rec *rec, uid_t uid);

/**
 * @brief       Update the image of the application
 * @param[in]   pkg_name        The application ID
 * @param[in]   comp_id         The component ID
 * @param[in]   instance_id     The instance ID
 * @param[in]   image           The image of the application
 * @return      0 on success, otherwise a nagative error value
 */
int rua_db_update_image(const char *pkg_name, const char *comp_id,
		const char *instance_id, const char *image);
int rua_usr_db_update_image(const char *pkg_name, const char *comp_id,
		const char *instance_id, const char *image, uid_t uid);

#ifdef __cplusplus
}
#endif
#endif		/*__RUA_INTERNAL_H__*/
