/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @file        rua_util.h
 * @brief       RUA UTIL API declaration header file.
 * @author      Hyunho Kang (hhstark.kang@samsung.com)
 * @version     0.1
 * @history     0.1: RUA UTIL API Declarations, structure declaration
 */

#ifndef __RUA_UTIL_H__
#define __RUA_UTIL_H__

#include <sys/types.h>

#include <sqlite3.h>

#define __BIND_TEXT(db, stmt, i, text)                                         \
do {                                                                           \
	if (sqlite3_bind_text(stmt, i, text, -1, SQLITE_STATIC) != SQLITE_OK) {\
		LOGE("bind error(index %d): %s", i, sqlite3_errmsg(db));       \
		sqlite3_finalize(stmt);                                        \
		return -1;                                                     \
	}                                                                      \
} while (0)

#define __BIND_INT(db, stmt, i, int)                                           \
do {                                                                           \
	if (sqlite3_bind_int(stmt, i, int) != SQLITE_OK) {                     \
		LOGE("bind error(index %d): %s", i, sqlite3_errmsg(db));       \
		sqlite3_finalize(stmt);                                        \
		return -1;                                                     \
	}                                                                      \
} while (0)

#define __BIND_DOUBLE(db, stmt, i, double)                                     \
do {                                                                           \
	if (sqlite3_bind_double(stmt, i, double) != SQLITE_OK) {               \
		LOGE("bind error(index %d): %s", i, sqlite3_errmsg(db));       \
		sqlite3_finalize(stmt);                                        \
		return -1;                                                     \
	}                                                                      \
} while (0)

char *_rua_util_get_db_path(uid_t uid, char *db_name);
int _rua_util_open_db(sqlite3 **db, int flags, uid_t uid, char *db_name);
int _rua_util_check_uid(uid_t target_uid);

#endif				/*__RUA_UTIL_H__*/
